@@ -32,7 +32,5 @@ unidentified_resource!(AnimationCurve);
 unidentified_resource!(Extension);
 unidentified_resource!(Font);
 unidentified_resource!(Path);
-unidentified_resource!(Room);
 unidentified_resource!(Sequence);
-unidentified_resource!(TileSet);
 unidentified_resource!(Timeline);
